pub struct UnifiedEventStream { /* private fields */ }Expand description
Builder that merges heterogeneous parquet cursors into a single chronological stream.
Implementations
Sourceimpl UnifiedEventStream
impl UnifiedEventStream
Sourcepub fn from_flight_recorder(
root: impl AsRef<Path>,
symbols: &[Symbol],
) -> Result<Self>
pub fn from_flight_recorder( root: impl AsRef<Path>, symbols: &[Symbol], ) -> Result<Self>
Construct a stream backed by parquet files located under a flight-recorder root.
Sourcepub fn from_paths(
symbols: &[Symbol],
tick_paths: Vec<PathBuf>,
order_book_paths: Vec<PathBuf>,
depth_paths: Vec<PathBuf>,
) -> Result<Self>
pub fn from_paths( symbols: &[Symbol], tick_paths: Vec<PathBuf>, order_book_paths: Vec<PathBuf>, depth_paths: Vec<PathBuf>, ) -> Result<Self>
Construct a stream from explicit parquet path lists.
Sourcepub fn into_stream(self) -> impl Stream<Item = Result<UnifiedEvent>>
pub fn into_stream(self) -> impl Stream<Item = Result<UnifiedEvent>>
Convert this stream into a futures::Stream implementation.