pub struct RecorderConfig {
pub root: PathBuf,
pub max_buffered_rows: usize,
pub flush_interval: Duration,
pub max_rows_per_file: usize,
pub channel_capacity: usize,
}Expand description
Configuration used when spawning a ParquetRecorder.
Fields
root: PathBufDirectory where all flight recorder data will be stored.
max_buffered_rows: usizeMaximum number of rows buffered in-memory before forcing a flush.
flush_interval: DurationHow often to flush buffers when traffic is low.
max_rows_per_file: usizeMaximum number of rows per parquet file before starting a new file.
channel_capacity: usizeCapacity of the asynchronous channel accepting recorder events.